==> haskell-microlens-mtl-0.2.0.1-16-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
key:                  microlens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  ecc1c5c4850143e8eead15598839fda1
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-FtqdtT70ljXCaWrzLLs7rg
depends:
    base-4.15.0.0 microlens-0.4.12.0-IoK2ncpVKVzEwRUasmz5D3 mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.1-27E2wCklav6CMkj1Ns7rzE

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microlens-mtl-0.2.0.1-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-microlens-mtl.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 microlens-mtl
version:              0.2.0.1
visibility:           public
id:                   microlens-mtl-0.2.0.1-HodO5uxSvp36cAcqpOnyRX
key:                  microlens-mtl-0.2.0.1-HodO5uxSvp36cAcqpOnyRX
license:              BSD-3-Clause
maintainer:           Monadfix <hi@monadfix.io>
author:               Edward Kmett, Artyom Kazak
homepage:             http://github.com/monadfix/microlens
synopsis:             microlens support for Reader/Writer/State from mtl
description:
    This package contains functions (like '\''view'\'' or '\''+='\'') which work on '\''MonadReader'\'', '\''MonadWriter'\'', and '\''MonadState'\'' from the mtl package.

    This package is a part of the <http://hackage.haskell.org/package/microlens microlens> family; see the readme <https://github.com/monadfix/microlens#readme on Github>.

category:             Data, Lenses
abi:                  97646dcf656e866b87f41f48d673d35f
exposed:              True
exposed-modules:      Lens.Micro.Mtl Lens.Micro.Mtl.Internal
import-dirs:          /usr/lib/ghc-9.0.2/site-local/microlens-mtl-0.2.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/microlens-mtl-0.2.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/microlens-mtl-0.2.0.1
hs-libraries:         HSmicrolens-mtl-0.2.0.1-HodO5uxSvp36cAcqpOnyRX
depends:
    base-4.15.1.0 microlens-0.4.12.0-1fJvmROd5lxEQCLdQ6LGgk mtl-2.2.2
    transformers-0.5.6.2
    transformers-compat-0.7.1-5G5J9BcZIFIGkjABObiUpP

haddock-interfaces:
    /usr/share/doc/haskell-microlens-mtl/html/microlens-mtl.haddock

haddock-html:         /usr/share/doc/haskell-microlens-mtl/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
